@@ -1,29 +1,9 @@
-/** ===========================================================
- * @file
- *
- * This file is a part of KDE project
- *
- *
- * @date   2012-08-06
- * @brief  Plugins config widget.
- *
- * @author Copyright (C) 2004-2017 by Gilles Caulier
- *         <a href="mailto:caulier dot gilles at gmail dot com">caulier dot gilles at gmail dot com</a>
- * @author Copyright (C) 2012      by Victor Dodon
- *         <a href="mailto:dodonvictor at gmail dot com">dodonvictor at gmail dot com</a>
- *
- * This program is free software; you can redistribute it
- * and/or modify it under the terms of the GNU General
- * Public License as published by the Free Software Foundation;
- * either version 2, or (at your option)
- * any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
- * GNU General Public License for more details.
- *
- * ============================================================ */
+/*
+    SPDX-FileCopyrightText: 2004-2018 Gilles Caulier <caulier dot gilles at gmail dot com>
+    SPDX-FileCopyrightText: 2012 Victor Dodon <dodonvictor at gmail dot com>
+
+    SPDX-License-Identifier: GPL-2.0-or-later
+*/
 
 #include "configwidget.h"
 
@@ -32,10 +12,10 @@
 #include <QList>
 #include <QHeaderView>
 
-// KDE includes
+// KF includes
 
-#include <ksharedconfig.h>
-#include <kconfiggroup.h>
+#include <KSharedConfig>
+#include <KConfigGroup>
 
 namespace KIPI
 {
@@ -70,7 +50,7 @@ public:
         setText(3, m_info->author().section(QString::fromLatin1(","), 0, 0));
     };
 
-    ~PluginCheckBox()
+    ~PluginCheckBox() override
     {
     };
 
@@ -89,7 +69,7 @@ public:
 
 // ---------------------------------------------------------------------
 
-class ConfigWidget::Private
+class Q_DECL_HIDDEN ConfigWidget::Private
 {
 public:
 
@@ -125,7 +105,8 @@ ConfigWidget::ConfigWidget(QWidget* const parent)
 
     if (loader)
     {
-        foreach(PluginLoader::Info* const info, loader->pluginList())
+        const auto infos = loader->pluginList();
+        for (PluginLoader::Info* const info : infos)
         {
             if (info)
             {
@@ -138,10 +119,7 @@ ConfigWidget::ConfigWidget(QWidget* const parent)
     sortItems(0, Qt::AscendingOrder);
 }
 
-ConfigWidget::~ConfigWidget()
-{
-    delete d;
-}
+ConfigWidget::~ConfigWidget() = default;
 
 void ConfigWidget::apply()
 {
@@ -150,7 +128,7 @@ void ConfigWidget::apply()
         KSharedConfigPtr config = KSharedConfig::openConfig();
         KConfigGroup group      = config->group(QString::fromLatin1("KIPI/EnabledPlugin"));
 
-        foreach (PluginCheckBox* const item, d->boxes)
+        for (PluginCheckBox* const item : std::as_const(d->boxes))
         {
             bool orig = item->m_info->shouldLoad();
             bool load = (item->checkState(0) == Qt::Checked);
@@ -168,13 +146,13 @@ void ConfigWidget::apply()
 
         config->sync();
 
-        emit PluginLoader::instance()->replug();
+        Q_EMIT PluginLoader::instance()->replug();
     }
 }
 
 void ConfigWidget::selectAll()
 {
-    foreach (PluginCheckBox* const item, d->boxes)
+    for (PluginCheckBox* const item : std::as_const(d->boxes))
     {
         item->setCheckState(0, Qt::Checked);
     }
@@ -182,7 +160,7 @@ void ConfigWidget::selectAll()
 
 void ConfigWidget::clearAll()
 {
-    foreach (PluginCheckBox* const item, d->boxes)
+    for (PluginCheckBox* const item : std::as_const(d->boxes))
     {
         item->setCheckState(0, Qt::Unchecked);
     }
@@ -197,7 +175,7 @@ int ConfigWidget::actived() const
 {
     int actived = 0;
 
-    foreach (PluginCheckBox* const item, d->boxes)
+    for (PluginCheckBox* const item : std::as_const(d->boxes))
     {
         if (item->checkState(0) == Qt::Checked)
             actived++;
@@ -210,7 +188,7 @@ int ConfigWidget::visible() const
 {
     int visible = 0;
 
-    foreach (PluginCheckBox* const item, d->boxes)
+    for (PluginCheckBox* const item : std::as_const(d->boxes))
     {
         if (!item->isHidden())
             visible++;
@@ -224,7 +202,7 @@ void ConfigWidget::setFilter(const QString& filter, Qt::CaseSensitivity cs)
     d->filter  = filter;
     bool query = false;
 
-    foreach (PluginCheckBox* const item, d->boxes)
+    for (PluginCheckBox* const item : std::as_const(d->boxes))
     {
         if (item->contains(filter, cs))
         {
@@ -237,7 +215,7 @@ void ConfigWidget::setFilter(const QString& filter, Qt::CaseSensitivity cs)
         }
     }
 
-    emit signalSearchResult(query);
+    Q_EMIT signalSearchResult(query);
 }
 
 QString ConfigWidget::filter() const
