@@ -1,35 +1,12 @@
-/** ===========================================================
- * @file
- *
- * This file is a part of KDE project
- *
- *
- * @date   2004-02-01
- * @brief  main kipi host application interface
- *
- * @author Copyright (C) 2004-2017 by Gilles Caulier
- *         <a href="mailto:caulier dot gilles at gmail dot com">caulier dot gilles at gmail dot com</a>
- * @author Copyright (C) 2006-2012 by Marcel Wiesweg
- *         <a href="mailto:marcel dot wiesweg at gmx dot de">marcel dot wiesweg at gmx dot de</a>
- * @author Copyright (C) 2004-2005 by Renchi Raju
- *         <a href="mailto:renchi dot raju at gmail dot com">renchi dot raju at gmail dot com</a>
- * @author Copyright (C) 2004-2005 by Jesper K. Pedersen
- *         <a href="mailto:blackie at kde dot org">blackie at kde dot org</a>
- * @author Copyright (C) 2004-2005 by Aurelien Gateau
- *         <a href="mailto:aurelien dot gateau at free dot fr">aurelien dot gateau at free dot fr</a>
- *
- * This program is free software; you can redistribute it
- * and/or modify it under the terms of the GNU General
- * Public License as published by the Free Software Foundation;
- * either version 2, or (at your option)
- * any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
- * GNU General Public License for more details.
- *
- * ============================================================ */
+/*
+    SPDX-FileCopyrightText: 2004-2018 Gilles Caulier <caulier dot gilles at gmail dot com>
+    SPDX-FileCopyrightText: 2006-2012 Marcel Wiesweg <marcel dot wiesweg at gmx dot de>
+    SPDX-FileCopyrightText: 2004-2005 Renchi Raju <renchi dot raju at gmail dot com>
+    SPDX-FileCopyrightText: 2004-2005 Jesper K. Pedersen <blackie at kde dot org>
+    SPDX-FileCopyrightText: 2004-2005 Aurelien Gateau <aurelien dot gateau at free dot fr>
+
+    SPDX-License-Identifier: GPL-2.0-or-later
+*/
 
 #include "interface.h"
 
@@ -189,7 +166,7 @@ void Interface::thumbnails(const QList<QUrl>& list, int size)
     for (QList<QUrl>::ConstIterator it = list.begin() ; it != list.end() ; ++it)
     {
         if ((*it).isValid())
-            emit gotThumbnail((*it), QPixmap());
+            Q_EMIT gotThumbnail((*it), QPixmap());
     }
 }
 
@@ -226,7 +203,7 @@ void Interface::preview(const QUrl& url, int resizedTo)
     PrintWarningMessageFeature("HostSupportsPreviews");
 
     if (url.isValid())
-        emit gotPreview(url, QImage());
+        Q_EMIT gotPreview(url, QImage());
 }
 
 QString Interface::rawFiles()
@@ -238,7 +215,7 @@ QString Interface::rawFiles()
 QAbstractItemModel* Interface::getTagTree() const
 {
     PrintWarningMessage();
-    return 0;
+    return nullptr;
 }
 
 QString Interface::progressScheduled(const QString& title, bool canBeCanceled, bool hasThumb) const
@@ -297,13 +274,13 @@ bool Interface::itemIsReserved(const QUrl&, QString* const) const
 FileReadWriteLock* Interface::createReadWriteLock(const QUrl&) const
 {
     PrintWarningMessageFeature("HostSupportsReadWriteLock");
-    return 0;
+    return nullptr;
 }
 
 MetadataProcessor* Interface::createMetadataProcessor() const
 {
     PrintWarningMessageFeature("HostSupportsMetadataProcessing");
-    return 0;
+    return nullptr;
 }
 
 void Interface::aboutToEdit(const QUrl&, EditHints)
@@ -317,10 +294,10 @@ void Interface::editingFinished(const QUrl&, EditHints)
 QStringList Interface::supportedImageMimeTypes(bool readWrite)
 {
     QStringList       mimeTypes;
-    QList<QByteArray> supported = readWrite ? QImageWriter::supportedMimeTypes()
-                                            : QImageReader::supportedMimeTypes();
+    const QList<QByteArray> supported = readWrite ? QImageWriter::supportedMimeTypes()
+                                                  : QImageReader::supportedMimeTypes();
 
-    Q_FOREACH(QByteArray mimeType, supported)
+    for (const QByteArray &mimeType : supported)
         mimeTypes.append(QString::fromLatin1(mimeType));
 
     return mimeTypes;
@@ -414,7 +391,7 @@ class Q_DECL_HIDDEN EditHintScope::Private
 public:
 
     Private() :
-        iface(0)
+        iface(nullptr)
     {
     }
 
@@ -444,8 +421,6 @@ EditHintScope::~EditHintScope()
     {
         d->iface->editingFinished(d->url, d->hints);
     }
-
-    delete d;
 }
 
 void EditHintScope::changeAborted()
