@@ -1,25 +1,9 @@
-/* ============================================================
- *
- * This file is a part of kipi-plugins project
- * http://www.digikam.org
- *
- * Date        : 2012-02-16
- * Description : an Hello World plugin using KDE XML-GUI technology.
- *
- * Copyright (C) 2012-2016 by Gilles Caulier <caulier dot gilles at gmail dot com>
- * Copyright (C) 2012      by Victor Dodon   <dodonvictor at gmail dot com>
- *
- * This program is free software; you can redistribute it
- * and/or modify it under the terms of the GNU General
- * Public License as published by the Free Software Foundation;
- * either version 2, or (at your option) any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * ============================================================ */
+/*
+    SPDX-FileCopyrightText: 2012-2018 Gilles Caulier <caulier dot gilles at gmail dot com>
+    SPDX-FileCopyrightText: 2012 Victor Dodon <dodonvictor at gmail dot com>
+
+    SPDX-License-Identifier: GPL-2.0-or-later
+*/
 
 /** Standard C++ header wrapper
  */
@@ -55,11 +39,11 @@ public:
         and const QStringList& args (the arguments passed).
     */
     Plugin_KXMLHelloWorld(QObject* const parent, const QVariantList& args);
-    ~Plugin_KXMLHelloWorld();
+    ~Plugin_KXMLHelloWorld() override;
 
     /** This method setup the plugin actions and connect internal signals and slots to handle plugin actions.
      */
-    void setup(QWidget* const widget);
+    void setup(QWidget* const widget) override;
 
 private Q_SLOTS:
 
